@@ -1,6 +1,5 @@
-require 'benchmark/base'
+require_relative 'base'
 
-$LOAD_PATH.unshift 'lib'
 require 'fast_gettext'
 include FastGettext::Translation
 
@@ -15,4 +14,4 @@ results_test{_('car') == 'Auto'}
 #i cannot add the large file, since its an internal applications mo file
 FastGettext.add_text_domain('large',:path=>locale_folder('large'))
 FastGettext.text_domain = 'large'
-results_large
\ No newline at end of file
+results_large
