@@ -7,6 +7,7 @@ module FastGettext
     class Mo < Base
       def initialize(name,options={})
         super
+        @eager_load = options.fetch(:eager_load, false)
         reload
       end
 
@@ -23,12 +24,16 @@ module FastGettext
         super
       end
 
+      def all_translations
+        current_translations.data
+      end
+
       protected
 
       def find_and_store_files(name,options)
         # parse all .mo files with the right name, that sit in locale/LC_MESSAGES folders
         find_files_in_locale_folders(File.join('LC_MESSAGES',"#{name}.mo"), options[:path]) do |locale,file|
-          MoFile.new(file)
+          MoFile.new(file, eager_load: @eager_load)
         end
       end
 
